@@ -7,6 +7,7 @@ from xml.etree import ElementTree as ET
 import pytest
 from hypothesis import assume, example, given, settings
 from hypothesis import strategies as st
+from hypothesis.extra.dateutil import timezones
 from hypothesis.strategies import integers
 from lxml.etree import XMLSyntaxError
 
@@ -17,7 +18,9 @@ from pikepdf.models.metadata import (
     XMP_NS_PDF,
     XMP_NS_XMP,
     DateConverter,
+    _fromisoformat_py36,
     decode_pdf_date,
+    fromisoformat,
 )
 
 try:
@@ -596,3 +599,35 @@ def test_issue_135_title_rdf_bag(trivial):
         xmp['dc:title'] = {'Title 1', 'Title 2'}
     with trivial.open_metadata(update_docinfo=False) as xmp:
         assert b'Title 1; Title 2</rdf:li></rdf:Alt></dc:title>' in xmp._get_xml_bytes()
+
+
+def test_xmp_metadatadate_timezone(sandwich, outpdf):
+    with sandwich.open_metadata():
+        pass
+    sandwich.save(outpdf)
+
+    machine_tz = datetime.utcnow().astimezone().tzinfo
+
+    with Pdf.open(outpdf) as pdf:
+        with pdf.open_metadata() as m:
+            dt = fromisoformat(m['xmp:MetadataDate'])
+            assert dt.tzinfo is not None
+            assert dt.tzinfo == machine_tz
+
+
+@given(st.datetimes())
+def test_py36_isoformat_microsecs(dt):
+    s = dt.isoformat()
+    assert _fromisoformat_py36(s) == dt
+
+
+@given(st.datetimes())
+def test_py36_isoformat_seconds(dt):
+    rounded_dt = dt.replace(microsecond=0)
+    s = rounded_dt.isoformat()
+    assert _fromisoformat_py36(s) == rounded_dt
+
+
+def test_py36_isoformat_invalid():
+    with pytest.raises(ValueError):
+        _fromisoformat_py36('not a datetime')
